@@ -22,13 +22,14 @@ Options:
 
 import sys
 from docopt import docopt
-
+from colorama import init
 from .handler import run_handler
 
 
 # ─── MAIN ───────────────────────────────────────────────────────────────────────
 
 def main():
+    init(autoreset=True)  # init colorama
     arguments = docopt(__doc__)
 
     try:
@@ -36,4 +37,4 @@ def main():
     except KeyboardInterrupt:
         sys.exit("Exiting...")
     except Exception as e:
-        print(e)
\ No newline at end of file
+        print(e)
